#
# spec file for package docker-distribution
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           docker-distribution
Version:        2.4.0
Release:        5.3
Summary:        The Docker toolset to pack, ship, store, and deliver content
License:        Apache-2.0
Group:          System/Management
Url:            http://www.docker.io
Source0:        distribution-%{version}.tar.xz
Source1:        registry-configuration.yml
Source2:        registry.service
Source3:        README-registry.SUSE
BuildRequires:  go >= 1.5.4
BuildRequires:  make
BuildRequires:  systemd-rpm-macros
Requires(pre):  %fillup_prereq
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
ExclusiveArch:  x86_64
%{?systemd_requires}

%description
The Docker toolset to pack, ship, store, and deliver content.

The main product of this repository is the new registry implementation for
storing and distributing docker images. It supersedes the docker/docker- registry
project with a new API design, focused around security and performance.

The Distribution project has the further long term goal of providing a secure
tool chain for distributing content. The specifications, APIs and tools shoulds
be as useful with docker as they are without.

%package registry
Summary:        Registry server for Docker
Group:          System/Management

%description registry
Registry server for Docker (hosting/delivering of repositories and images).

%prep
%setup -q -n distribution-%{version}
cp %{SOURCE3} .

%build
export GOPATH=$PWD/go
mkdir -p $GOPATH/src/github.com/docker

# Copy the vendor directory into the GOPATH.
cp -r $PWD/vendor/* $GOPATH/src
ln -s $PWD $GOPATH/src/github.com/docker/distribution

make %{?_smp_mflags} binaries

%install
install -D -m755 bin/registry %{buildroot}/%{_bindir}/registry
install -D -m644 %{SOURCE1} %{buildroot}/%{_sysconfdir}/registry/config.yml
install -d  %{buildroot}%{_localstatedir}/lib/docker-registry

#
# systemd service for registry
#
install -Dd -m 0755  %{buildroot}%{_sbindir}
install -D  -m 0644  %{SOURCE2} %{buildroot}%{_unitdir}/registry.service
ln -sv %{_sbindir}/service %{buildroot}%{_sbindir}/rcregistry

%pre registry
%service_add_pre registry.service

%post registry
%service_add_post registry.service
%{fillup_only -n registry}

%preun registry
%service_del_preun registry.service

%postun registry
%service_del_postun registry.service

%files registry
%defattr(-,root,root)
%{_bindir}/registry
%{_sbindir}/rcregistry
%{_unitdir}/registry.service
%config %{_sysconfdir}/registry
%config %{_sysconfdir}/registry/config.yml
%doc LICENSE README.md README-registry.SUSE
%{_localstatedir}/lib/docker-registry

%changelog
* Thu Apr 14 2016 msabate@suse.com
- Upgraded to 2.4.0. Changelog:
  * New S3 storage driver
  The default s3 storage driver is now implemented on top of the official Amazon
  S3 SDK, boasting major performance and stability goodness. The previous storage
  is still available, but deprecated.
  * Garbage Collector
  A garbage collector tool has been added to the registry. For more details see
  the garbage collector documentation.
  * Tagged Manifest Events
  Manifest push and pull events will now include the tag which was used in the
  operation (if applicable).
  * Relative URLs
  The registry can now be configured to return relative URLs in Location headers.
  * V1 Signature disabled
  With the ongoing adoption of the schema 2 manifest format and deprecation of
  signatures, this option will improve pull performance by generating and
  returning a single libtrust signature.
  * Gotchas
  The RADOS storage driver has been removed. The registry can still be used with
  Ceph as the storage backend using the swift driver in conjunction with the
  Swift API gateway.
  The command line format has changed to support subcommands. To run a registry
  as before an additional subcommand - serve - is required.
  The legacy S3 storage driver, based on adroll/goamz is now deprecated and will
  be removed in a future release.
* Thu Mar 10 2016 msabate@suse.com
- Updated changelog
  bsc#970507
  The fix_version.patch file has been removed because it has been fixed upstream
* Thu Mar 10 2016 msabate@suse.com
- Removed old tarball
* Thu Mar 10 2016 msabate@suse.com
- Ugraded to 2.3.1. The changelog is as follows:
- Allow uppercase characters in hostnames (https://github.com/docker/distribution/commit/34c3acf8a8d800524ac06444290b26ed96d4dac0)
- Fix schema1 manifest etag and docker content digest header (https://github.com/docker/distribution/commit/d7eb5d118a6a14a6f320062296b1808506c35241)
- Add option to disable signatures (https://github.com/docker/distribution/commit/d1c173078fe47f45c7f7b96098410d4f13dd68ab)
- To avoid any network use unless necessary, delay establishing authorization (https://github.com/docker/distribution/commit/740ed699f40e1522faacb2a706e44fa1560af8ea)
- Extend authChallenger interface to remove type cast.  (https://github.com/docker/distribution/commit/16445b67679e91eab408a40a34625aa1f4dabfd1)
- Enable proxying registries to downgrade fetched manifests to Schema 1.  (https://github.com/docker/distribution/commit/36936218c2e6a4527fc99a5c04126bb1f4c7d55c)
* Fri Feb  5 2016 msabate@suse.com
- Update to 2.3
  This Docker Registry release is the first to support the Image Manifest
  Version 2, Schema 2 manifest format.
* Wed Sep 23 2015 jmassaguerpla@suse.com
- set exclusive arch to x86_64 since this is the only arch we build for
* Mon Sep  7 2015 jmassaguerpla@suse.com
- Update to 2.1.1 (bsc#948097)
  This release provides a bug fix where the filesystem layout of manifests was
  not backwards compatible with v2.0.x registries.
- Update to 2.1.0
  - Support for listing Registry repositories
  - Manifest and layer soft deletion
  - Pull through caching (experimental)
  - Storage Drivers
  more details on: https://github.com/docker/distribution/releases
  add fix_version.patch: fix version to 2.1.1 instead of git version
* Fri May 29 2015 fcastelli@suse.com
- Added README-registry.SUSE
* Fri May 29 2015 fcastelli@suse.com
- Create /etc/registry to hold all the configuration files of registry
* Thu May 14 2015 fcastelli@suse.com
- Update to 2.0.1:
  * Enable blob streaming upload
  * S3 consistency checking and better resource utilization
  * Eliminate resource leakage in the notification system
  * Request error and storage driver logging
  * Documentation corrections and additions
* Fri Apr 17 2015 fcastelli@suse.com
- Update to 2.0.0: first stable release of distribution
* Thu Apr 16 2015 fcastelli@suse.com
- Update to 2.0.0-rc4:  Several fixes have been made to contextual logging
  output, including ensuring accurate http response status, authorized user
  name and correct output of the version.
* Thu Apr  9 2015 fcastelli@suse.com
- Created initial package
